import json
import re

import pytest
import yaml
from requests import Session


class Base:
    # 创建Session，记录cookies，cookies提供给之后的每个请求调用。 Session参数可维持一段时间
    def __init__(self):
        self.session = Session()
        with open("../datafiles/env.yml") as f:
            env = yaml.safe_load(f)
        # 解耦环境使用（450版本之后）
        self.paas_url = env["eminxing"]["paas_url"] + '/console/'
        self.devops_url = env["eminxing"]["devops_url"]
        self.login_url = env["eminxing"]["paas_url"] + '/login/?c_url: ' + self.devops_url + '/console/platform/entry'
        self.username = env["eminxing"]["username"]
        self.password = env["eminxing"]["password"]
        # 登录后，把相关cookie信息存入session
        login = self.login()
        print("登录接口cookies：", login.cookies)
        self.session.cookies.set("X-DEVOPS-TENANT-ID", self.get_tenant_id())
        self.session.cookies.set("X-DEVOPS-TOKEN", self.get_devops_token())
        self.session.cookies.set("X-DEVOPS-UID", self.username)
        # 把项目id存入session
        self.project_id = self.get_project_list()
        self.session.cookies.set("X_DEVOPS_PROJECT_ID", self.project_id)
        print("打印的cookie如下：", self.session.cookies)

    # 访问paas平台登录地址获取bklogin_token提供登录使用
    def get_bk_login_token(self):
        r = self.session.get(self.paas_url)
        bk_login_token = ((re.compile("ftoken=(.*?); expires")).findall(str(r.headers)))[0]
        print("bk_login_token获取到的值如下：", bk_login_token)
        return bk_login_token

    # 获取devops_token
    def get_devops_token(self):
        devops_token_url = self.devops_url + "/ms/permission/api/user/tenant/token"
        r = self.session.get(devops_token_url).text
        devops_token = json.loads(r)["data"]
        print("devops_token获取到的值如下：", devops_token)
        return devops_token

    # 在租户列表取特定的租户标识，比如bk_ci
    def get_tenant_id(self):
        tenant_id_url = self.devops_url + "/ms/permission/api/user/tenant/listByUser"
        # tenant_id_url = self.devops_url + "/ms/permission/api/user/tenant?page=1&pageSize=1000"
        r = json.loads(self.session.get(tenant_id_url).text)
        tenant_id = ""
        for item in r['data']:
            if item["code"] == "JC_AUTO_Test":
                tenant_id = item["code"]
                print("登录的租户为：", item["name"])
                break
        if tenant_id == "":
            raise Exception("该租户不存在(JC_AUTO_Test)")
        return tenant_id

    # 获取工作项模型的id
    def get_issue_model_id(self):
        issue_model_id_url = self.devops_url + "/ms/vteam/api/user/issue_model?text=项目工作项模型"
        r = self.session.get(issue_model_id_url).text
        issue_model_id = json.loads(r)["data"][-1]["id"]
        print("获取到的倒数第一个issue_model_id（bk_ci）的值如下：", issue_model_id)
        return issue_model_id

    # #   查询项目工作项模型id并返回，暂时用不上
    # def get_issue_id(self):
    #     a = self.session.get(self.__login_url.IssueIdUrl).text
    #     return json.loads(a)["data"][0]["id"]

    # 将project_id设置进cookies中

    # 把project_id写入cookie
    def set_project_id(self):
        self.session.cookies.set("X_DEVOPS_PROJECT_ID", self.project_id)
        print("写入cookies的project为： ", self.project_id)

    # devops登录，需要传三个参数：csrfmiddlewaretoken, username, password
    def login(self):
        bk_login_token = self.get_bk_login_token()
        data = {
            "csrfmiddlewaretoken": bk_login_token,
            "username": self.username,
            "password": self.password
        }
        print("登录传的参数为：", data)
        r = self.session.post(url=self.login_url, data=data)
        return r

    # # 创建项目
    # def create_project(self):
    #     """
    #     根据查询的项目信息，检验项目是否存在
    #     如果存在，那么直接返回yml文件中存储的project_id；
    #     如果不存在，将会创建新的项目，并把项目id写入yml文件，同时也返回project_id
    #     :return: project_id
    #     """
    #     result = self.get_project_info()
    #     if result != 0:
    #         issue_model_id = self.get_issue_model_id()
    #         data = {
    #             "templateId": "100000000000002",
    #             "relationDemand": "",
    #             "relationProject": "",
    #             "projectName": "JC_API_AutoTest",
    #             "englishNameCustom": "jcapiautotest",
    #             "deptId": "1",
    #             "description": "",
    #             "administrator": "Jolie",
    #             "issueId": issue_model_id,
    #             "typeId": "2",
    #             "props": [],
    #             "roleTemplates": ""
    #         }
    #         create_project_url = self.devops_url + "/ms/project/api/user/projectProps?issueId="
    #         url = create_project_url + issue_model_id
    #         print("创建项目的URL如下：", url)
    #         r = self.session.post(url=url, json=data).text
    #         project_id_new = json.loads(r)['data']
    #         print('项目ID为：', project_id_new)
    #         # 把创建项目后的项目id写入文件，覆盖原来的项目id
    #         with open("./ProjectId.yml", "w+") as w:
    #             w.write(project_id_new)
    #         return project_id_new
    #     else:
    #         with open("./ProjectId.yml") as f:
    #             project_id_old = f.readline()
    #         return project_id_old

    # # 获取项目信息，没有过滤被删除的项目。原因为项目删除为假删，数据库还有数据
    # def get_project_info(self):
    #     f = open("./ProjectId.yml")
    #     project_id = f.readline()
    #     print("读取文件内容输出为：", project_id)
    #     url = self.devops_url + "/ms/project/api/user/project/cw/getInfo?projectId=" + project_id
    #     print("查询项目信息的URL为：", url)
    #     r = self.session.get(url)
    #     print("根据yml文件中的项目id查询项目是否存在", r.text)
    #     result = r.json()["status"]
    #     return result

    # 查询项目列表（已过滤删除的项目）
    def get_project_list(self):
        url = self.devops_url + "/ms/project/api/user/project/cw/selectByType?name=&status=USING&showTree=true&typeId=2"
        r = self.session.get(url).text
        project_list = json.loads(r)["data"]
        # print(type(project_list))
        project_code_list = [item["projectCode"] for item in project_list]
        # print(project_code_list)
        with open("../datafiles/ProjectId.yml") as f:
            project_id = f.readline()
        if project_id in project_code_list:
            print("项目存在，id如下：", project_id)
            return project_id
        else:
            print("项目不存在，即将创建新项目......")
            issue_model_id = self.get_issue_model_id()
            data = {
                "templateId": "100000000000002",
                "relationDemand": "",
                "relationProject": "",
                "projectName": "JC_API_AutoTest",
                "englishNameCustom": "jcapiautotest",
                "deptId": "1",
                "description": "",
                "administrator": "Jolie",
                "issueId": issue_model_id,
                "typeId": "2",
                "props": [],
                "roleTemplates": ""
            }
            create_project_url = self.devops_url + "/ms/project/api/user/projectProps?issueId="
            url = create_project_url + issue_model_id
            print("创建项目的URL如下：", url)
            r = self.session.post(url=url, json=data).text
            project_id_new = json.loads(r)['data']
            print('项目ID为：', project_id_new)
            # 把创建项目后的项目id写入文件，覆盖原来的项目id
            with open("../datafiles/ProjectId.yml", "w+") as w:
                w.write(project_id_new)
            return project_id_new
