from src.test.CTest.common.base import Base


class CaseLevel(Base):
    # 创建用例等级
    def create_case_level(self, case_level_name, case_level_description, color):
        """
        创建用例等级
        :param case_level_name: 等级名称
        :param case_level_description:等级描述
        :param color:选择颜色
        :return:
        """
        data = {
            "name": case_level_name,
            "description": case_level_description,
            "color": color
        }
        create_case_level_url = self.devops_url + "/ms/ctest/api/user/case_level"
        print(create_case_level_url)
        r = self.session.post(url=create_case_level_url, json=data)
        return r

    # 编辑用例等级
    def edit_case_level(self, case_level_name, case_level_description, color, case_level_id):
        """
        编辑用例等级
        :param case_level_name: 等级名称
        :param case_level_description: 等级描述
        :param color: 选择颜色
        :param case_level_id: 用例等级id
        :return:
        """
        data = {
            "name": case_level_name,
            "description": case_level_description,
            "color": color,
            "id": case_level_id
        }
        edit_case_level_url = self.devops_url + "/ms/ctest/api/user/case_level"
        print(edit_case_level_url)
        r = self.session.put(url=edit_case_level_url, json=data)
        return r

    # 设置默认用例等级
    def set_case_level_default(self, case_level_id):
        """
        设置默认用例等级
        :param case_level_id: 等级名称
        :return:
        """
        set_case_level_default_url = self.devops_url + "/ms/ctest/api/user/case_level/default/" + case_level_id
        print(set_case_level_default_url)
        r = self.session.put(url=set_case_level_default_url)
        return r

    # 用例等级拖动排序
    def set_case_level_sequence(self, case_level_list):
        data = case_level_list
        set_case_level_sequence_url = self.devops_url + "/ms/ctest/api/user/case_level/sort"
        print(set_case_level_sequence_url)
        r = self.session.post(url=set_case_level_sequence_url, json=data)
        return r

    # 查询单个用例等级
    def get_case_level_detail(self, case_level_id):
        get_case_level_detail_url = self.devops_url + "/ms/ctest/api/user/case_level/" + case_level_id
        print(get_case_level_detail_url)
        r = self.session.get(url=get_case_level_detail_url)
        return r

    # 删除用例等级
    def delete_case_level(self, case_level_id):
        delete_case_level_url = self.devops_url + "/ms/ctest/api/user/case_level/" + case_level_id
        print(delete_case_level_url)
        r = self.session.delete(url=delete_case_level_url)
        return r

    # 校验等级名称是否重名
    def get_case_level_unique(self, case_level_name):
        params = {"keyword": case_level_name}
        get_case_level_unique_url = self.devops_url + "/ms/ctest/api/user/case_level/unique"
        print(get_case_level_unique_url)
        r = self.session.get(url=get_case_level_unique_url, params=params)
        return r

    # 查询用例等级是否关联用例
    def get_case_level_relation(self, case_level_id):
        get_case_level_relation_url = self.devops_url + "/ms/ctest/api/user/case_level/" + case_level_id
        print(get_case_level_relation_url)
        r = self.session.get(url=get_case_level_relation_url)
        return r

    # 查询用例等级列表
    def get_case_level_list(self):
        get_case_level_list_url = self.devops_url + "/ms/ctest/api/user/case_level/list"
        print(get_case_level_list_url)
        r = self.session.get(url=get_case_level_list_url)
        return r

    # 查询可选的等级颜色
    def get_case_level_color(self):
        get_case_level_color_url = self.devops_url + "/ms/ctest/api/user/case_level/color"
        print(get_case_level_color_url)
        r = self.session.get(url=get_case_level_color_url)
        return r
