from src.test.CTest.common.base import Base


class SystemTree(Base):
    def create_system_tree(self, name, tree_type, parent_id):
        """
        创建系统或分组
        :param name: 系统名称或分组名称，系统名称字符限制50字符，分组字符限制20字符
        :param tree_type: 系统使用SYSTEM，分组使用GROUP
        :param parent_id: 子级系统或者分组关联的父级id
        :return:接口返回
        """
        data = {
            "name": name,
            "type": tree_type,
            "parentId": parent_id
        }
        create_system_tree_url = self.devops_url + "/ms/ctest/api/user/system_tree"
        r = self.session.post(url=create_system_tree_url, json=data)
        return r

    def edit_system_tree(self, name, tree_type, system_tree_id):
        """
        编辑系统或分组
        :param name: 系统名称或分组名称，系统名称字符限制50字符，分组字符限制20字符
        :param tree_type: 系统使用SYSTEM，分组使用GROUP
        :param system_tree_id: 系统或分组的id
        :return: 接口返回
        """
        data = {
            "name": name,
            "type": tree_type,
            "id": system_tree_id
        }
        edit_system_tree_url = self.devops_url + "/ms/ctest/api/user/system_tree"
        r = self.session.put(url=edit_system_tree_url, json=data)
        return r

    def delete_system_tree(self, system_tree_id):
        """
        删除系统或分组
        :param system_tree_id: 系统或分组id
        :return: 接口返回
        """
        delete_system_tree_url = self.devops_url + "/ms/ctest/api/user/system_tree/" + system_tree_id
        print("删除系统功能树的URL地址为：" + delete_system_tree_url)
        r = self.session.delete(url=delete_system_tree_url)
        return r

    def get_system_tree_page(self, page, pagesize, name):
        """
        分页查询系统功能树
        :param page: 页码
        :param pagesize: 每页大小
        :param name: 系统或分组关键字
        :return:
        """
        params = {
            "page": page,
            "pageSize": pagesize,
            "keyword": name
        }
        get_system_tree_page_url = self.devops_url + "/ms/ctest/api/user/system_tree/page"
        r = self.session.get(url=get_system_tree_page_url, params=params)
        return r

    def get_system_tree_tile(self, search_name):
        """
        系统平铺查询
        :param search_name:关键字
        :return:接口返回
        """
        params = {"keyword": search_name}
        get_system_tree_tile_url = self.devops_url + "/ms/ctest/api/user/system_tree/system/tile"
        r = self.session.get(url=get_system_tree_tile_url, params=params)
        return r

    def get_case_library_tree(self, name):
        """
        用例库【分组】查询系统或分组
        :param name: 系统或分组关键字
        :return:
        """
        data = {
            "systemKeyword": name,
            "filterNoCase": False,
            "caseKeyword": name,
            "filter": {
                "baseFilter": [],
                "customFilter": []
            }
        }
        get_case_library_tree_url = self.devops_url + "/ms/ctest/api/user/system_tree/case_library/tree"
        r = self.session.post(url=get_case_library_tree_url, json=data)
        return r
