import allure
import pytest

from src.test.CTest.pages.case_level import CaseLevel


@allure.feature("用例等级")
class TestCaseLevel:
    def setup_class(self):
        self.level = CaseLevel()

    def test_create_case_level_case001(self):
        """创建用例等级"""
        # 先查询可选的等级颜色,selected=true为已使用，selected=false为未使用
        r1 = self.level.get_case_level_color()
        color_list = r1.json()["data"]
        # print(color_list)
        unselected_color = [item['color'] for item in color_list if item['selected'] == False]
        print("用例等级未被使用的颜色如下", unselected_color)
        r2 = self.level.create_case_level(case_level_name="C1", case_level_description="这是创建用例等级的描述",
                                          color=unselected_color[0])
        assert r2.status_code == 200 and r2.json()["status"] == 0
        print("成功创建用例等级")
        # 数据清理：获取用例等级id，然后进行删除操作
        case_level_id = r2.json()['data']
        self.level.delete_case_level(case_level_id)

    def test_create_case_level_case002(self):
        """不允许创建同名的用例等级"""
        # 先查询可选的等级颜色,selected=true为已使用，selected=false为未使用
        r1 = self.level.get_case_level_color()
        color_list = r1.json()["data"]
        # print(color_list)
        unselected_color = [item['color'] for item in color_list if item['selected'] == False]
        print("用例等级未被使用的颜色如下", unselected_color)
        r2 = self.level.create_case_level(case_level_name="U1", case_level_description="这是创建用例等级的描述",
                                          color=unselected_color[0])
        assert r2.status_code == 200 and r2.json()["status"] == 0
        print("成功创建用例等级")
        # 获取用例等级id
        case_level_id1 = r2.json()['data']
        # 用例等级名称重名校验
        r3 = self.level.get_case_level_unique(case_level_name="U1")
        try:
            assert r3.status_code == 200 and r3.json()["status"] == 0 and r3.json()["data"] == False
            print("用例等级名称重名", r3.text)
        except Exception as e:
            assert r3.json()["data"] == True
            print("用例等级名称不重名，允许继续创建用例等级")
        # 数据清理：获取用例等级id，然后进行删除操作
        self.level.delete_case_level(case_level_id1)

    def test_create_case_level_case003(self):
        """创建用例等级名称不允许超过4个字符"""
        # 先查询可选的等级颜色,selected=true为已使用，selected=false为未使用
        r1 = self.level.get_case_level_color()
        color_list = r1.json()["data"]
        # print(color_list)
        unselected_color = [item['color'] for item in color_list if item['selected'] == False]
        print("用例等级未被使用的颜色如下", unselected_color)
        r2 = self.level.create_case_level(case_level_name="LONGT", case_level_description="这是用例等级名称超过4个字符的描述",
                                          color=unselected_color[0])
        assert r2.status_code == 200 and r2.json()["status"] == 990102 and r2.json()["message"] == "等级名称限定不超过4字符"
        print("创建用例等级的名称超过4个字符，不允许创建", r2.text)

    def test_create_case_level_case004(self):
        """创建用例等级描述不允许超过50个字符"""
        # 先查询可选的等级颜色,selected=true为已使用，selected=false为未使用
        r1 = self.level.get_case_level_color()
        color_list = r1.json()["data"]
        # print(color_list)
        unselected_color = [item['color'] for item in color_list if item['selected'] == False]
        print("用例等级未被使用的颜色如下", unselected_color)
        r2 = self.level.create_case_level(case_level_name="L1",
                                          case_level_description="这是创建用例等级的描述超过50"
                                                                 "字符的测试这是创建用例等级的描述超过50"
                                                                 "字符的测试这是创建用例等级的描述超过50字符的测试",
                                          color=unselected_color[0])
        assert r2.status_code == 200 and r2.json()["status"] == 990102 and r2.json()["message"] == "描述限定不超过50字符"
        print("创建用例等级的描述超过50个字符，不允许创建", r2.text)

    def test_edit_case_level(self):
        """编辑用例等级"""
        # 先查询可选的等级颜色,selected=true为已使用，selected=false为未使用
        r1 = self.level.get_case_level_color()
        # print(r1.text)
        color_list = r1.json()["data"]
        # print(color_list)
        unselected_color = [item['color'] for item in color_list if item['selected'] == False]
        print("用例等级未被使用的颜色如下", unselected_color)
        # 创建用例等级，获取用例等级id
        r2 = self.level.create_case_level(case_level_name="E1", case_level_description="这是编辑用例等级的描述",
                                          color=unselected_color[0])
        assert r2.status_code == 200 and r2.json()["status"] == 0
        case_level_id = r2.json()['data']
        # 编辑用例等级
        r3 = self.level.edit_case_level(case_level_name="E1改", case_level_description="这是编辑用例等级的描述--修改描述内容",
                                        color=unselected_color[0], case_level_id=case_level_id)
        assert r3.status_code == 200 and r3.json()["status"] == 0 and r3.json()["data"] == True
        print("成功编辑用例等级")
        # 数据清理：删除用例等级
        self.level.delete_case_level(case_level_id)

    def test_get_case_level_list(self):
        """查看用例等级列表"""
        r = self.level.get_case_level_list()
        assert r.status_code == 200 and r.json()["status"] == 0
        print("用例等级列表查询如下", r.text)

    def test_set_case_level_default(self):
        """设置默认等级"""
        # 查询用例等级列表，获取非默认等级的id
        r1 = self.level.get_case_level_list()
        case_level_list = r1.json()['data']
        defaulted_case_level = [item['id'] for item in case_level_list if item['default'] == True]
        not_defaulted_case_level_list = [item['id'] for item in case_level_list if item['default'] == False]
        print("默认的用例等级id如下：", defaulted_case_level)
        print("非默认的用例等级id如下：", not_defaulted_case_level_list)
        # 把非默认用例等级的第一个设置为默认等级
        r2 = self.level.set_case_level_default(not_defaulted_case_level_list[0])
        assert r2.status_code == 200 and r2.json()["status"] == 0 and r2.json()["data"] == True
        print("成功设置默认用例等级", r2.text)
        # 恢复为原来的默认用例等级
        self.level.set_case_level_default(defaulted_case_level[0])

    def test_set_case_level_sequence(self):
        """改变用例等级顺序"""
        # 查询用例等级列表
        case_level_list = self.level.get_case_level_list().json()["data"]
        case_level_list_id = [item['id'] for item in case_level_list]
        case_level_list_name = [item['name'] for item in case_level_list]
        print("当前用例等级列表排序(id)如下：", case_level_list_id)
        print("当前用例等级列表排序(name)如下：", case_level_list_name)
        # 倒序排列
        sort_list_id1 = case_level_list_id[::-1]
        # list转换为str进行单引号替换为双引号，然后再转换为list
        sort_list_id2 = eval(str(sort_list_id1).replace("'", '"'))
        print("倒序排列的用例等级列表(id)如下：", sort_list_id2)
        # 用例等级列表排序
        r1 = self.level.set_case_level_sequence(case_level_list=sort_list_id2)
        assert r1.status_code == 200 and r1.json()["status"] == 0
        print("用例等级排序操作成功", r1.text)
        # 再次查询用例等级列表，获取当前排序后的用例等级名称
        case_level_list = self.level.get_case_level_list().json()["data"]
        sort_list_name = [item['name'] for item in case_level_list]
        print("倒序排列后用例等级列表排序（name）如下：", sort_list_name)
        # 恢复为原来的用例等级排序
        self.level.set_case_level_sequence(case_level_list=case_level_list_id)

    def test_delete_case_level_case001(self):
        """删除用例等级"""
        # 先查询可选的等级颜色,selected=true为已使用，selected=false为未使用
        r1 = self.level.get_case_level_color()
        color_list = r1.json()["data"]
        # print(color_list)
        unselected_color = [item['color'] for item in color_list if item['selected'] == False]
        print("用例等级未被使用的颜色如下", unselected_color)
        r2 = self.level.create_case_level(case_level_name="D1", case_level_description="这是即将被删除的用例等级的描述",
                                          color=unselected_color[0])
        assert r2.status_code == 200 and r2.json()["status"] == 0
        case_level_id = r2.json()['data']
        r3 = self.level.delete_case_level(case_level_id)
        assert r3.status_code == 200 and r3.json()["status"] == 0 and r3.json()["data"] == True
        print("成功删除用例等级", r3.text)

    def test_delete_case_level_case002(self):
        """不允许删除已被用例引用的用例等级。待补充"""
        pass
