import allure

from src.test.CTest.pages.system_tree import SystemTree


@allure.feature("系统功能树")
class TestSystemTree:
    def setup_class(self):
        self.system_tree = SystemTree()

    def test_create_system_tree_case001(self):
        """
        创建一级系统
        :return:
        """
        r = self.system_tree.create_system_tree(name="JC-AUTOTest-SystemTree", tree_type="SYSTEM", parent_id="")
        assert r.status_code == 200 and r.json()["status"] == 0
        print("成功创建一级系统")
        system_tree_id = r.json()["data"]
        r1 = self.system_tree.delete_system_tree(system_tree_id)
        assert r1.status_code == 200 and r1.json()["status"] == 0 and r1.json()["data"] == True

    def test_create_system_tree_case002(self):
        """
        创建五个层级的系统
        :return:
        """
        tree_type = "SYSTEM"
        parent_id = ""
        # 创建五个层级的系统
        for i in range(5):
            name = "JC-SubSystemTree-Create" + str(i)
            r = self.system_tree.create_system_tree(name=name, tree_type=tree_type, parent_id=parent_id)
            parent_id = r.json()["data"]
            assert r.status_code == 200 and r.json()["status"] == 0
            print("已成功创建第" + str(i) + "层级的系统")
        # 查询系统功能树列表获取一级系统的id，然后删除系统
        r1 = self.system_tree.get_system_tree_page(page=1, pagesize=200, name="JC-SubSystemTree-Create")
        first_parent_id = r1.json()["data"]["records"][0]["id"]
        r2 = self.system_tree.delete_system_tree(first_parent_id)
        assert r2.status_code == 200 and r2.json()["status"] == 0 and r2.json()["data"] == True

    def test_create_system_tree_case003(self):
        """
        创建八个层级分组
        :return:
        """
        # 先创建系统，获取系统id
        r = self.system_tree.create_system_tree(name="JC-SystemTree-Group", tree_type="SYSTEM", parent_id="")
        parent_id = r.json()["data"]
        tree_type = "GROUP"
        # 创建八个层级的分组
        for i in range(8):
            name = "JC-SubGroup-Create" + str(i)
            r1 = self.system_tree.create_system_tree(name=name, tree_type=tree_type, parent_id=parent_id)
            parent_id = r1.json()["data"]
            assert r.status_code == 200 and r.json()["status"] == 0
            print("已成功创建第" + str(i) + "层级的分组")
        # 查询系统功能树列表获取一级系统的id，然后删除系统（删除系统，同步删除系统下的所有分组）
        r2 = self.system_tree.get_system_tree_page(page=1, pagesize=200, name="JC-SubGroup-Create")
        first_parent_id = r2.json()["data"]["records"][0]["id"]
        r3 = self.system_tree.delete_system_tree(first_parent_id)
        assert r3.status_code == 200 and r3.json()["status"] == 0 and r3.json()["data"] == True

    def test_edit_system_tree_case001(self):
        """
        编辑系统名称
        :return:
        """
        # 创建系统获取id
        r = self.system_tree.create_system_tree(name="JC-SystemTree-Edit", tree_type="SYSTEM", parent_id="")
        assert r.status_code == 200 and r.json()["status"] == 0
        system_tree_id = r.json()["data"]
        # 编辑系统名称
        r1 = self.system_tree.edit_system_tree(name="JC-SystemTree-Edit-Modify", tree_type="SYSTEM",
                                               system_tree_id=system_tree_id)
        assert r1.status_code == 200 and r1.json()["status"] == 0 and r1.json()["data"] == True
        print("成功编辑系统名称")
        # 删除系统
        r2 = self.system_tree.delete_system_tree(system_tree_id)
        assert r2.status_code == 200 and r2.json()["status"] == 0 and r2.json()["data"] == True

    def test_edit_system_tree_case002(self):
        """
        编辑分组名称
        :return:
        """
        # 创建系统获取id
        r = self.system_tree.create_system_tree(name="JC-GroupTree-Edit", tree_type="SYSTEM", parent_id="")
        assert r.status_code == 200 and r.json()["status"] == 0
        system_tree_id = r.json()["data"]
        # 创建分组获取分组id
        r1 = self.system_tree.create_system_tree(name="JC-SubGroupTree-Edit", tree_type="GROUP",
                                                 parent_id=system_tree_id)
        assert r1.status_code == 200 and r1.json()["status"] == 0
        group_tree_id = r1.json()["data"]
        # 编辑分组名称
        r2 = self.system_tree.edit_system_tree(name="JC-SubGroupTree-M", tree_type="GROUP",
                                               system_tree_id=group_tree_id)
        assert r2.status_code == 200 and r2.json()["status"] == 0 and r2.json()["data"] == True
        print("成功编辑分组名称")
        # 删除分组、系统
        self.system_tree.delete_system_tree(group_tree_id)
        self.system_tree.delete_system_tree(system_tree_id)

    def test_delete_system_tree_case001(self):
        """
        删除系统
        :return:
        """
        # 创建系统
        r = self.system_tree.create_system_tree(name="JC-SystemTree-Delete", tree_type="SYSTEM", parent_id="")
        assert r.status_code == 200 and r.json()["status"] == 0
        system_tree_id = r.json()["data"]
        # 删除系统
        r1 = self.system_tree.delete_system_tree(system_tree_id)
        assert r1.status_code == 200 and r1.json()["status"] == 0 and r1.json()["data"] == True
        print("成功删除系统")

    def test_delete_system_tree_case002(self):
        """
        删除分组
        :return:
        """
        # 创建系统获取id
        r = self.system_tree.create_system_tree(name="JC-GroupTree-Delete", tree_type="SYSTEM", parent_id="")
        assert r.status_code == 200 and r.json()["status"] == 0
        system_tree_id = r.json()["data"]
        # 创建分组获取分组id
        r1 = self.system_tree.create_system_tree(name="JC-SubGroup-Delete", tree_type="GROUP",
                                                 parent_id=system_tree_id)
        assert r1.status_code == 200 and r1.json()["status"] == 0
        group_tree_id = r1.json()["data"]
        # 删除分组
        r2 = self.system_tree.delete_system_tree(group_tree_id)
        assert r2.status_code == 200 and r2.json()["status"] == 0 and r2.json()["data"] == True
        print("成功删除分组")
        self.system_tree.delete_system_tree(system_tree_id)

    def test_get_system_tree_page(self):
        r = self.system_tree.get_system_tree_page(page=1, pagesize=200, name="")
        assert r.status_code == 200 and r.json()["status"] == 0
        print("系统功能树分页查询正常")
        print(r.text)

    def test_get_system_tree_tile(self):
        r = self.system_tree.get_system_tree_tile(search_name="")
        assert r.status_code == 200 and r.json()["status"] == 0
        print("系统平铺查询正常")
        print(r.text)

    def test_get_case_library_tree(self):
        r = self.system_tree.get_case_library_tree(name="")
        assert r.status_code == 200 and r.json()["status"] == 0
        print("用例库【分组】查询系统或分组正常")
        print(r.text)
